pub enum Hook {
BeforeLog(Box<dyn Fn(LogLevel, &TargetId) + Send + Sync>),
AfterLog(Box<dyn Fn(LogLevel, &TargetId) + Send + Sync>),
}Expand description
Represents a hook that can be set to trigger at specific points in the logging process.
Hooks can be used to perform custom actions, for example, for performing side effects, such as clearing the console or sending notifications.
Hooks are executed in the order they are added.
Variants
BeforeLog(Box<dyn Fn(LogLevel, &TargetId) + Send + Sync>)
Hook that is called before a log message is written.
AfterLog(Box<dyn Fn(LogLevel, &TargetId) + Send + Sync>)
Hook that is called after a log message is written. This is useful for post-processing or additional actions.