Enum TargetId

pub enum TargetId {
    Console(Output),
    File(PathBuf),
    Custom(String),
}
Represents the id of the target where the log message is written. This can be a console output, file path, or a custom string identifier. Useful for identifying the target in hooks / filters.

Variants



Console(Output)

Console output target



File(PathBuf)

File output target



Custom(String)

Custom target identifier This can be used for custom targets that don’t fit into the predefined categories.